pub const fn exhaustive_chars() -> ExhaustiveChars ⓘExpand description
Generates all chars, in a friendly order, so that more familiar chars come first.
The order is
- Lowercase ASCII letters,
- Uppercase ASCII letters,
- ASCII digits,
- Graphic ASCII
char(not alphanumeric and not control), including' 'but no other whitespace, - Graphic Non-ASCII
chars; all non-ASCIIchars whoseDebugrepresentations don’t start with'\', - All remaining
chars.
Within each group, the chars are ordered according to their usual order.
If you want to generate chars in their usual order, try chars_increasing.
The output length is 1,112,064.
Complexity per iteration
Constant time and additional memory.
Examples
use malachite_base::chars::exhaustive::exhaustive_chars;
assert_eq!(
exhaustive_chars().take(200).collect::<String>(),
"abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789 !\"#$%&\'()*+,-./:;<=>?@[\\\
]^_`{|}~¡¢£¤¥¦¨©ª«¬®¯°±²³´µ¶·¸¹º»¼½¾¿ÀÁÂÃÄÅÆÇÈÉÊËÌÍÎÏÐÑÒÓÔÕÖרÙÚÛÜÝÞßàáâãäåæçèéêëìíîïðñòóô\
õö÷øùúûüýþÿĀāĂ㥹ĆćĈĉĊ"
);