AbsDiff

Trait AbsDiff 

pub trait AbsDiff<RHS = Self> {
    type Output;

    // Required method
    fn abs_diff(self, other: RHS) -> Self::Output;
}
Subtracts two numbers and takes the absolute value of the difference.

Required Associated Types

Required Methods

fn abs_diff(self, other: RHS) -> Self::Output

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl AbsDiff for i8

Source

fn abs_diff(self, other: i8) -> u8

This is a wrapper over the abs_diff functions in the standard library, for example this one.

Source

type Output = u8

Source

impl AbsDiff for i16

Source

fn abs_diff(self, other: i16) -> u16

This is a wrapper over the abs_diff functions in the standard library, for example this one.

Source

type Output = u16

Source

impl AbsDiff for i32

Source

fn abs_diff(self, other: i32) -> u32

This is a wrapper over the abs_diff functions in the standard library, for example this one.

Source

type Output = u32

Source

impl AbsDiff for i64

Source

fn abs_diff(self, other: i64) -> u64

This is a wrapper over the abs_diff functions in the standard library, for example this one.

Source

type Output = u64

Source

impl AbsDiff for i128

Source

fn abs_diff(self, other: i128) -> u128

This is a wrapper over the abs_diff functions in the standard library, for example this one.

Source

type Output = u128

Source

impl AbsDiff for isize

Source

fn abs_diff(self, other: isize) -> usize

This is a wrapper over the abs_diff functions in the standard library, for example this one.

Source

type Output = usize

Source

impl AbsDiff for u8

Source

fn abs_diff(self, other: u8) -> u8

This is a wrapper over the abs_diff functions in the standard library, for example this one.

Source

type Output = u8

Source

impl AbsDiff for u16

Source

fn abs_diff(self, other: u16) -> u16

This is a wrapper over the abs_diff functions in the standard library, for example this one.

Source

type Output = u16

Source

impl AbsDiff for u32

Source

fn abs_diff(self, other: u32) -> u32

This is a wrapper over the abs_diff functions in the standard library, for example this one.

Source

type Output = u32

Source

impl AbsDiff for u64

Source

fn abs_diff(self, other: u64) -> u64

This is a wrapper over the abs_diff functions in the standard library, for example this one.

Source

type Output = u64

Source

impl AbsDiff for u128

Source

fn abs_diff(self, other: u128) -> u128

This is a wrapper over the abs_diff functions in the standard library, for example this one.

Source

type Output = u128

Source

impl AbsDiff for usize

Source

fn abs_diff(self, other: usize) -> usize

This is a wrapper over the abs_diff functions in the standard library, for example this one.

Source

type Output = usize

Implementors