ModPowerOf2NegAssign

Trait ModPowerOf2NegAssign 

pub trait ModPowerOf2NegAssign {
    // Required method
    fn mod_power_of_2_neg_assign(&mut self, pow: u64);
}
Negates a number modulo $2^k$ in place. The input must be already reduced modulo $2^k$.

Required Methods

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl ModPowerOf2NegAssign for u8

Source

fn mod_power_of_2_neg_assign(&mut self, pow: u64)

Negates a number modulo another number $2^k$, in place. The input must be already reduced modulo $2^k$.

$x \gets y$, where $x, y < 2^k$ and $-x \equiv y \mod 2^k$.

Worst-case complexity

Constant time and additional memory.

Panics

Panics if pow is greater than Self::WIDTH or if self is greater than or equal to $2^k$.

Examples

See here.

Source

impl ModPowerOf2NegAssign for u16

Source

fn mod_power_of_2_neg_assign(&mut self, pow: u64)

Negates a number modulo another number $2^k$, in place. The input must be already reduced modulo $2^k$.

$x \gets y$, where $x, y < 2^k$ and $-x \equiv y \mod 2^k$.

Worst-case complexity

Constant time and additional memory.

Panics

Panics if pow is greater than Self::WIDTH or if self is greater than or equal to $2^k$.

Examples

See here.

Source

impl ModPowerOf2NegAssign for u32

Source

fn mod_power_of_2_neg_assign(&mut self, pow: u64)

Negates a number modulo another number $2^k$, in place. The input must be already reduced modulo $2^k$.

$x \gets y$, where $x, y < 2^k$ and $-x \equiv y \mod 2^k$.

Worst-case complexity

Constant time and additional memory.

Panics

Panics if pow is greater than Self::WIDTH or if self is greater than or equal to $2^k$.

Examples

See here.

Source

impl ModPowerOf2NegAssign for u64

Source

fn mod_power_of_2_neg_assign(&mut self, pow: u64)

Negates a number modulo another number $2^k$, in place. The input must be already reduced modulo $2^k$.

$x \gets y$, where $x, y < 2^k$ and $-x \equiv y \mod 2^k$.

Worst-case complexity

Constant time and additional memory.

Panics

Panics if pow is greater than Self::WIDTH or if self is greater than or equal to $2^k$.

Examples

See here.

Source

impl ModPowerOf2NegAssign for u128

Source

fn mod_power_of_2_neg_assign(&mut self, pow: u64)

Negates a number modulo another number $2^k$, in place. The input must be already reduced modulo $2^k$.

$x \gets y$, where $x, y < 2^k$ and $-x \equiv y \mod 2^k$.

Worst-case complexity

Constant time and additional memory.

Panics

Panics if pow is greater than Self::WIDTH or if self is greater than or equal to $2^k$.

Examples

See here.

Source

impl ModPowerOf2NegAssign for usize

Source

fn mod_power_of_2_neg_assign(&mut self, pow: u64)

Negates a number modulo another number $2^k$, in place. The input must be already reduced modulo $2^k$.

$x \gets y$, where $x, y < 2^k$ and $-x \equiv y \mod 2^k$.

Worst-case complexity

Constant time and additional memory.

Panics

Panics if pow is greater than Self::WIDTH or if self is greater than or equal to $2^k$.

Examples

See here.

Implementors