MulAddMulAssign

Trait MulAddMulAssign 

pub trait MulAddMulAssign<Y = Self, Z = Self, W = Self> {
    // Required method
    fn mul_add_mul_assign(&mut self, y: Y, z: Z, w: W);
}
Adds the products of two pairs of numbers, in place.

Required Methods

fn mul_add_mul_assign(&mut self, y: Y, z: Z, w: W)

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl MulAddMulAssign for i8

Source

fn mul_add_mul_assign(&mut self, y: i8, z: i8, w: i8)

Adds the products of two pairs of numbers, in place.

$x \gets xy + zw$.

Both products and their sum wrap on overflow, as they do for add_mul.

Worst-case complexity

Constant time and additional memory.

Examples

See here.

Source

impl MulAddMulAssign for i16

Source

fn mul_add_mul_assign(&mut self, y: i16, z: i16, w: i16)

Adds the products of two pairs of numbers, in place.

$x \gets xy + zw$.

Both products and their sum wrap on overflow, as they do for add_mul.

Worst-case complexity

Constant time and additional memory.

Examples

See here.

Source

impl MulAddMulAssign for i32

Source

fn mul_add_mul_assign(&mut self, y: i32, z: i32, w: i32)

Adds the products of two pairs of numbers, in place.

$x \gets xy + zw$.

Both products and their sum wrap on overflow, as they do for add_mul.

Worst-case complexity

Constant time and additional memory.

Examples

See here.

Source

impl MulAddMulAssign for i64

Source

fn mul_add_mul_assign(&mut self, y: i64, z: i64, w: i64)

Adds the products of two pairs of numbers, in place.

$x \gets xy + zw$.

Both products and their sum wrap on overflow, as they do for add_mul.

Worst-case complexity

Constant time and additional memory.

Examples

See here.

Source

impl MulAddMulAssign for i128

Source

fn mul_add_mul_assign(&mut self, y: i128, z: i128, w: i128)

Adds the products of two pairs of numbers, in place.

$x \gets xy + zw$.

Both products and their sum wrap on overflow, as they do for add_mul.

Worst-case complexity

Constant time and additional memory.

Examples

See here.

Source

impl MulAddMulAssign for isize

Source

fn mul_add_mul_assign(&mut self, y: isize, z: isize, w: isize)

Adds the products of two pairs of numbers, in place.

$x \gets xy + zw$.

Both products and their sum wrap on overflow, as they do for add_mul.

Worst-case complexity

Constant time and additional memory.

Examples

See here.

Source

impl MulAddMulAssign for u8

Source

fn mul_add_mul_assign(&mut self, y: u8, z: u8, w: u8)

Adds the products of two pairs of numbers, in place.

$x \gets xy + zw$.

Both products and their sum wrap on overflow, as they do for add_mul.

Worst-case complexity

Constant time and additional memory.

Examples

See here.

Source

impl MulAddMulAssign for u16

Source

fn mul_add_mul_assign(&mut self, y: u16, z: u16, w: u16)

Adds the products of two pairs of numbers, in place.

$x \gets xy + zw$.

Both products and their sum wrap on overflow, as they do for add_mul.

Worst-case complexity

Constant time and additional memory.

Examples

See here.

Source

impl MulAddMulAssign for u32

Source

fn mul_add_mul_assign(&mut self, y: u32, z: u32, w: u32)

Adds the products of two pairs of numbers, in place.

$x \gets xy + zw$.

Both products and their sum wrap on overflow, as they do for add_mul.

Worst-case complexity

Constant time and additional memory.

Examples

See here.

Source

impl MulAddMulAssign for u64

Source

fn mul_add_mul_assign(&mut self, y: u64, z: u64, w: u64)

Adds the products of two pairs of numbers, in place.

$x \gets xy + zw$.

Both products and their sum wrap on overflow, as they do for add_mul.

Worst-case complexity

Constant time and additional memory.

Examples

See here.

Source

impl MulAddMulAssign for u128

Source

fn mul_add_mul_assign(&mut self, y: u128, z: u128, w: u128)

Adds the products of two pairs of numbers, in place.

$x \gets xy + zw$.

Both products and their sum wrap on overflow, as they do for add_mul.

Worst-case complexity

Constant time and additional memory.

Examples

See here.

Source

impl MulAddMulAssign for usize

Source

fn mul_add_mul_assign(&mut self, y: usize, z: usize, w: usize)

Adds the products of two pairs of numbers, in place.

$x \gets xy + zw$.

Both products and their sum wrap on overflow, as they do for add_mul.

Worst-case complexity

Constant time and additional memory.

Examples

See here.

Implementors