pub trait NegModAssign<RHS = Self> {
// Required method
fn neg_mod_assign(&mut self, other: RHS);
}Expand description
Divides the negative of a number by another number, replacing the first number by the remainder.
If the quotient were computed, the quotient and remainder would satisfy $x = qy - r$ and $0 \leq r < y$.
Required Methods
fn neg_mod_assign(&mut self, other: RHS)
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl NegModAssign for u8
impl NegModAssign for u8
Sourcefn neg_mod_assign(&mut self, other: u8)
fn neg_mod_assign(&mut self, other: u8)
Divides the negative of a number by another number, returning just the remainder.
If the quotient were computed, the quotient and remainder would satisfy $x = qy - r$ and $0 \leq r < y$.
$$ x \gets y\left \lceil \frac{x}{y} \right \rceil - x. $$
Worst-case complexity
Constant time and additional memory.
Panics
Panics if other is 0.
Examples
See here.
Sourceimpl NegModAssign for u16
impl NegModAssign for u16
Sourcefn neg_mod_assign(&mut self, other: u16)
fn neg_mod_assign(&mut self, other: u16)
Divides the negative of a number by another number, returning just the remainder.
If the quotient were computed, the quotient and remainder would satisfy $x = qy - r$ and $0 \leq r < y$.
$$ x \gets y\left \lceil \frac{x}{y} \right \rceil - x. $$
Worst-case complexity
Constant time and additional memory.
Panics
Panics if other is 0.
Examples
See here.
Sourceimpl NegModAssign for u32
impl NegModAssign for u32
Sourcefn neg_mod_assign(&mut self, other: u32)
fn neg_mod_assign(&mut self, other: u32)
Divides the negative of a number by another number, returning just the remainder.
If the quotient were computed, the quotient and remainder would satisfy $x = qy - r$ and $0 \leq r < y$.
$$ x \gets y\left \lceil \frac{x}{y} \right \rceil - x. $$
Worst-case complexity
Constant time and additional memory.
Panics
Panics if other is 0.
Examples
See here.
Sourceimpl NegModAssign for u64
impl NegModAssign for u64
Sourcefn neg_mod_assign(&mut self, other: u64)
fn neg_mod_assign(&mut self, other: u64)
Divides the negative of a number by another number, returning just the remainder.
If the quotient were computed, the quotient and remainder would satisfy $x = qy - r$ and $0 \leq r < y$.
$$ x \gets y\left \lceil \frac{x}{y} \right \rceil - x. $$
Worst-case complexity
Constant time and additional memory.
Panics
Panics if other is 0.
Examples
See here.
Sourceimpl NegModAssign for u128
impl NegModAssign for u128
Sourcefn neg_mod_assign(&mut self, other: u128)
fn neg_mod_assign(&mut self, other: u128)
Divides the negative of a number by another number, returning just the remainder.
If the quotient were computed, the quotient and remainder would satisfy $x = qy - r$ and $0 \leq r < y$.
$$ x \gets y\left \lceil \frac{x}{y} \right \rceil - x. $$
Worst-case complexity
Constant time and additional memory.
Panics
Panics if other is 0.
Examples
See here.
Sourceimpl NegModAssign for usize
impl NegModAssign for usize
Sourcefn neg_mod_assign(&mut self, other: usize)
fn neg_mod_assign(&mut self, other: usize)
Divides the negative of a number by another number, returning just the remainder.
If the quotient were computed, the quotient and remainder would satisfy $x = qy - r$ and $0 \leq r < y$.
$$ x \gets y\left \lceil \frac{x}{y} \right \rceil - x. $$
Worst-case complexity
Constant time and additional memory.
Panics
Panics if other is 0.
Examples
See here.