WrappingAbs

Trait WrappingAbs 

pub trait WrappingAbs {
    type Output;

    // Required method
    fn wrapping_abs(self) -> Self::Output;
}
Takes the absolute value of a number, wrapping around at the boundary of the type.

Required Associated Types

Required Methods

fn wrapping_abs(self) -> Self::Output

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl WrappingAbs for i8

Source

fn wrapping_abs(self) -> i8

This is a wrapper over the wrapping_abs functions in the standard library, for example this one.

Source

type Output = i8

Source

impl WrappingAbs for i16

Source

fn wrapping_abs(self) -> i16

This is a wrapper over the wrapping_abs functions in the standard library, for example this one.

Source

type Output = i16

Source

impl WrappingAbs for i32

Source

fn wrapping_abs(self) -> i32

This is a wrapper over the wrapping_abs functions in the standard library, for example this one.

Source

type Output = i32

Source

impl WrappingAbs for i64

Source

fn wrapping_abs(self) -> i64

This is a wrapper over the wrapping_abs functions in the standard library, for example this one.

Source

type Output = i64

Source

impl WrappingAbs for i128

Source

fn wrapping_abs(self) -> i128

This is a wrapper over the wrapping_abs functions in the standard library, for example this one.

Source

type Output = i128

Source

impl WrappingAbs for isize

Source

fn wrapping_abs(self) -> isize

This is a wrapper over the wrapping_abs functions in the standard library, for example this one.

Source

type Output = isize

Implementors