Trait WrappingAddAssign
Source pub trait WrappingAddAssign<RHS = Self> {
// Required method
fn wrapping_add_assign(&mut self, other: RHS);
}
Adds a number to another number in place, wrapping around at the boundary of the type.
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Adds a number to another number in place, wrapping around at the boundary of the
type.
$x \gets z$, where $z \equiv x + y \mod 2^W$ and $W$ is Self::WIDTH.
Worst-case complexity
Constant time and additional memory.
Examples
See here.
Adds a number to another number in place, wrapping around at the boundary of the
type.
$x \gets z$, where $z \equiv x + y \mod 2^W$ and $W$ is Self::WIDTH.
Worst-case complexity
Constant time and additional memory.
Examples
See here.
Adds a number to another number in place, wrapping around at the boundary of the
type.
$x \gets z$, where $z \equiv x + y \mod 2^W$ and $W$ is Self::WIDTH.
Worst-case complexity
Constant time and additional memory.
Examples
See here.
Adds a number to another number in place, wrapping around at the boundary of the
type.
$x \gets z$, where $z \equiv x + y \mod 2^W$ and $W$ is Self::WIDTH.
Worst-case complexity
Constant time and additional memory.
Examples
See here.
Adds a number to another number in place, wrapping around at the boundary of the
type.
$x \gets z$, where $z \equiv x + y \mod 2^W$ and $W$ is Self::WIDTH.
Worst-case complexity
Constant time and additional memory.
Examples
See here.
Adds a number to another number in place, wrapping around at the boundary of the
type.
$x \gets z$, where $z \equiv x + y \mod 2^W$ and $W$ is Self::WIDTH.
Worst-case complexity
Constant time and additional memory.
Examples
See here.
Adds a number to another number in place, wrapping around at the boundary of the
type.
$x \gets z$, where $z \equiv x + y \mod 2^W$ and $W$ is Self::WIDTH.
Worst-case complexity
Constant time and additional memory.
Examples
See here.
Adds a number to another number in place, wrapping around at the boundary of the
type.
$x \gets z$, where $z \equiv x + y \mod 2^W$ and $W$ is Self::WIDTH.
Worst-case complexity
Constant time and additional memory.
Examples
See here.
Adds a number to another number in place, wrapping around at the boundary of the
type.
$x \gets z$, where $z \equiv x + y \mod 2^W$ and $W$ is Self::WIDTH.
Worst-case complexity
Constant time and additional memory.
Examples
See here.
Adds a number to another number in place, wrapping around at the boundary of the
type.
$x \gets z$, where $z \equiv x + y \mod 2^W$ and $W$ is Self::WIDTH.
Worst-case complexity
Constant time and additional memory.
Examples
See here.
Adds a number to another number in place, wrapping around at the boundary of the
type.
$x \gets z$, where $z \equiv x + y \mod 2^W$ and $W$ is Self::WIDTH.
Worst-case complexity
Constant time and additional memory.
Examples
See here.
Adds a number to another number in place, wrapping around at the boundary of the
type.
$x \gets z$, where $z \equiv x + y \mod 2^W$ and $W$ is Self::WIDTH.
Worst-case complexity
Constant time and additional memory.
Examples
See here.