pub trait WrappingDivAssign<RHS = Self> {
// Required method
fn wrapping_div_assign(&mut self, other: RHS);
}Expand description
Divides a number by another number in place, wrapping around at the boundary of the type.
Required Methods
fn wrapping_div_assign(&mut self, other: RHS)
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl WrappingDivAssign for i8
impl WrappingDivAssign for i8
Sourcefn wrapping_div_assign(&mut self, other: i8)
fn wrapping_div_assign(&mut self, other: i8)
Divides a number by another number in place, wrapping around at the boundary of the type.
Wrapping only occurs when Self is signed, self is Self::MIN, and other is
-1. The “actual” result, -Self::MIN, can’t be represented and is wrapped back to
Self::MIN.
Worst-case complexity
Constant time and additional memory.
Examples
See here.
Sourceimpl WrappingDivAssign for i16
impl WrappingDivAssign for i16
Sourcefn wrapping_div_assign(&mut self, other: i16)
fn wrapping_div_assign(&mut self, other: i16)
Divides a number by another number in place, wrapping around at the boundary of the type.
Wrapping only occurs when Self is signed, self is Self::MIN, and other is
-1. The “actual” result, -Self::MIN, can’t be represented and is wrapped back to
Self::MIN.
Worst-case complexity
Constant time and additional memory.
Examples
See here.
Sourceimpl WrappingDivAssign for i32
impl WrappingDivAssign for i32
Sourcefn wrapping_div_assign(&mut self, other: i32)
fn wrapping_div_assign(&mut self, other: i32)
Divides a number by another number in place, wrapping around at the boundary of the type.
Wrapping only occurs when Self is signed, self is Self::MIN, and other is
-1. The “actual” result, -Self::MIN, can’t be represented and is wrapped back to
Self::MIN.
Worst-case complexity
Constant time and additional memory.
Examples
See here.
Sourceimpl WrappingDivAssign for i64
impl WrappingDivAssign for i64
Sourcefn wrapping_div_assign(&mut self, other: i64)
fn wrapping_div_assign(&mut self, other: i64)
Divides a number by another number in place, wrapping around at the boundary of the type.
Wrapping only occurs when Self is signed, self is Self::MIN, and other is
-1. The “actual” result, -Self::MIN, can’t be represented and is wrapped back to
Self::MIN.
Worst-case complexity
Constant time and additional memory.
Examples
See here.
Sourceimpl WrappingDivAssign for i128
impl WrappingDivAssign for i128
Sourcefn wrapping_div_assign(&mut self, other: i128)
fn wrapping_div_assign(&mut self, other: i128)
Divides a number by another number in place, wrapping around at the boundary of the type.
Wrapping only occurs when Self is signed, self is Self::MIN, and other is
-1. The “actual” result, -Self::MIN, can’t be represented and is wrapped back to
Self::MIN.
Worst-case complexity
Constant time and additional memory.
Examples
See here.
Sourceimpl WrappingDivAssign for isize
impl WrappingDivAssign for isize
Sourcefn wrapping_div_assign(&mut self, other: isize)
fn wrapping_div_assign(&mut self, other: isize)
Divides a number by another number in place, wrapping around at the boundary of the type.
Wrapping only occurs when Self is signed, self is Self::MIN, and other is
-1. The “actual” result, -Self::MIN, can’t be represented and is wrapped back to
Self::MIN.
Worst-case complexity
Constant time and additional memory.
Examples
See here.
Sourceimpl WrappingDivAssign for u8
impl WrappingDivAssign for u8
Sourcefn wrapping_div_assign(&mut self, other: u8)
fn wrapping_div_assign(&mut self, other: u8)
Divides a number by another number in place, wrapping around at the boundary of the type.
Wrapping only occurs when Self is signed, self is Self::MIN, and other is
-1. The “actual” result, -Self::MIN, can’t be represented and is wrapped back to
Self::MIN.
Worst-case complexity
Constant time and additional memory.
Examples
See here.
Sourceimpl WrappingDivAssign for u16
impl WrappingDivAssign for u16
Sourcefn wrapping_div_assign(&mut self, other: u16)
fn wrapping_div_assign(&mut self, other: u16)
Divides a number by another number in place, wrapping around at the boundary of the type.
Wrapping only occurs when Self is signed, self is Self::MIN, and other is
-1. The “actual” result, -Self::MIN, can’t be represented and is wrapped back to
Self::MIN.
Worst-case complexity
Constant time and additional memory.
Examples
See here.
Sourceimpl WrappingDivAssign for u32
impl WrappingDivAssign for u32
Sourcefn wrapping_div_assign(&mut self, other: u32)
fn wrapping_div_assign(&mut self, other: u32)
Divides a number by another number in place, wrapping around at the boundary of the type.
Wrapping only occurs when Self is signed, self is Self::MIN, and other is
-1. The “actual” result, -Self::MIN, can’t be represented and is wrapped back to
Self::MIN.
Worst-case complexity
Constant time and additional memory.
Examples
See here.
Sourceimpl WrappingDivAssign for u64
impl WrappingDivAssign for u64
Sourcefn wrapping_div_assign(&mut self, other: u64)
fn wrapping_div_assign(&mut self, other: u64)
Divides a number by another number in place, wrapping around at the boundary of the type.
Wrapping only occurs when Self is signed, self is Self::MIN, and other is
-1. The “actual” result, -Self::MIN, can’t be represented and is wrapped back to
Self::MIN.
Worst-case complexity
Constant time and additional memory.
Examples
See here.
Sourceimpl WrappingDivAssign for u128
impl WrappingDivAssign for u128
Sourcefn wrapping_div_assign(&mut self, other: u128)
fn wrapping_div_assign(&mut self, other: u128)
Divides a number by another number in place, wrapping around at the boundary of the type.
Wrapping only occurs when Self is signed, self is Self::MIN, and other is
-1. The “actual” result, -Self::MIN, can’t be represented and is wrapped back to
Self::MIN.
Worst-case complexity
Constant time and additional memory.
Examples
See here.
Sourceimpl WrappingDivAssign for usize
impl WrappingDivAssign for usize
Sourcefn wrapping_div_assign(&mut self, other: usize)
fn wrapping_div_assign(&mut self, other: usize)
Divides a number by another number in place, wrapping around at the boundary of the type.
Wrapping only occurs when Self is signed, self is Self::MIN, and other is
-1. The “actual” result, -Self::MIN, can’t be represented and is wrapped back to
Self::MIN.
Worst-case complexity
Constant time and additional memory.
Examples
See here.