Traits for converting numbers to and from Strings.
Modules
- from_
sci_ string FromSciString, a trait for converting strings, possibly using scientific notation, to numbers.- from_
string FromStringBase, a trait for converting strings in a specified base to numbers.- latex
ToLateximplementations for primitive integers and primitive floats, converting them to LaTeX math-mode fragments.- options
ToSciOptionsandFromSciSringOptions,structs for specifying parameters when using theFromSciStringandToScitraits.- to_sci
ToSci, a trait for converting a number to string, possibly using scientific notation.- to_
string - The
BaseFmtWrapperstruct andToStringBasetrait, used for converting numbers to strings. - typst
ToTypstimplementations for primitive integers and primitive floats, converting them to Typst math-mode fragments.