Module from_string

Module from_string 

FromStringBase, a trait for converting strings in a specified base to numbers.

Functions

digit_from_display_byte
Produces a digit from a byte corresponding to a numeric or alphabetic (lower- or uppercase) char that represents the digit.
digit_from_display_byte_large
Converts a byte corresponding to a numeric or alphabetic char to a digit in the large-base alphabet used for bases from 37 through 62, in which the uppercase and lowercase letters are distinct digits: b'0' through b'9' represent 0 through 9, b'A' through b'Z' represent 10 through 35, and b'a' through b'z' represent 36 through 61, as in GMP.