Factors

Struct Factors 

pub struct Factors<T: PrimitiveUnsigned, const N: usize> { /* private fields */ }
A struct that contains the prime factorization of an integer. See implementations of the Factor trait for more information.