Module random

Module random 

Iterators that generate Options randomly.

Structs

RandomOptions
Generates random Options with values from a given random iterator.
RandomSomes
Generates random Options except None, with values from a given random iterator.

Functions

random_options
Generates random Options with values from a given random iterator.
random_somes
Generates random Options except None, with values from a given random iterator.