Integral

Trait Integral 

pub trait Integral {
    type Output;

    // Required method
    fn integral(self) -> Self::Output;
}
Computes the integral of a polynomial whose constant term is zero, $\sum_i a_ix^{i+1}/(i+1)$.

Required Associated Types

Required Methods

fn integral(self) -> Self::Output

Computes the integral of a polynomial whose constant term is zero.

$$ f(p) = \int_0^x p(t),dt. $$

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors