ModAddTruncatedAssign

Trait ModAddTruncatedAssign 

pub trait ModAddTruncatedAssign<Rhs = Self, M = Self> {
    // Required method
    fn mod_add_truncated_assign(&mut self, other: Rhs, len: u64, m: M);
}
Adds a polynomial to another modulo $m$ in place, keeping only the coefficients of $x^i$ for $i$ less than a given length. The coefficients of both must already be reduced modulo $m$.

With $n$ equal to len, this is addition in the ring of polynomials with coefficients modulo $m$, taken modulo $x^n$, applied to the images of the two polynomials there. Unlike the coefficients, which must already be reduced, the polynomials need not already be truncated: they may have any number of coefficients, and only the first len of each are read.

Required Methods

fn mod_add_truncated_assign(&mut self, other: Rhs, len: u64, m: M)

Adds a polynomial to self modulo $m$ and truncates the sum to its first len coefficients.

$$ p \gets ((p + q) \bmod x^n) \bmod m. $$

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors