Module random

Module random 

Iterators that generate sets randomly.

Structs

RandomBTreeSets
Generates random BTreeSets with lengths from an iterator.
RandomBTreeSetsFixedLength
Generates random BTreeSets of a fixed length, where the Vecs have no repeated elements, and the elements are in ascending order.
RandomHashSets
Generates random HashSets with lengths from an iterator.
RandomHashSetsFixedLength
Generates random HashSets of a fixed length, where the Vecs have no repeated elements, and the elements are in ascending order.

Functions

random_b_tree_sets
Generates random BTreeSets using elements from an iterator.
random_b_tree_sets_fixed_length
Randomly generates BTreeSets of a given length.
random_b_tree_sets_from_length_iterator
Generates random BTreeSets using elements from an iterator and with lengths from another iterator.
random_b_tree_sets_length_inclusive_range
Generates random BTreeSets with lengths in $[a, b]$, using elements from an iterator.
random_b_tree_sets_length_range
Generates random BTreeSets with lengths in $[a, b]$, using elements from an iterator.
random_b_tree_sets_min_length
Generates random BTreeSets with a minimum length, using elements from an iterator.
random_hash_sets
Generates random HashSets using elements from an iterator.
random_hash_sets_fixed_length
Randomly generates HashSets of a given length.
random_hash_sets_from_length_iterator
Generates random HashSets using elements from an iterator and with lengths from another iterator.
random_hash_sets_length_inclusive_range
Generates random HashSets with lengths in $[a, b]$, using elements from an iterator.
random_hash_sets_length_range
Generates random HashSets with lengths in $[a, b)$, using elements from an iterator.
random_hash_sets_min_length
Generates random HashSets with a minimum length, using elements from an iterator.