pub fn exhaustive_pairs_from_single<I: Iterator>(
xs: I,
) -> ExhaustivePairs1Input<I> ⓘExpand description
This documentation applies not only to exhaustive_pairs_from_single, but also to
exhaustive_triples_from_single, exhaustive_quadruples_from_single, and so on. See
exhaustive_tuples_1_input for more information.
Generates all $n$-tuples with elements from a single iterator.
If xs is finite, the output length is $k^n$, where $k$ is xs.count() and $n$ is the
width of the tuples. If xs is infinite, the output is also infinite.
If xs is empty, the output is also empty.
Examples
See here.