Module unsigned_polynomial

Module unsigned_polynomial 

UnsignedPolynomial, a type representing polynomials in one variable whose coefficients are primitive unsigned integers.

Modules

arithmetic
Traits for arithmetic on UnsignedPolynomials.
comparison
Implementations of Ord and PartialOrd for UnsignedPolynomial, comparing two polynomials by their behavior for large arguments.
conversion
Functions for converting a UnsignedPolynomial to and from other types.
exhaustive
Iterators that generate UnsignedPolynomials without repetition.
random
Iterators that generate UnsignedPolynomials randomly.

Structs

UnsignedPolynomial
A polynomial in one variable whose coefficients are unsigned primitive integers.