RandomUnsignedPolynomialsFromUnsigneds

Type Alias RandomUnsignedPolynomialsFromUnsigneds 

pub type RandomUnsignedPolynomialsFromUnsigneds<T> = RandomUnsignedPolynomials<T, GeometricRandomNaturalValues<u64>, RandomPolynomialCoefficients<T>, RandomPolynomialLeadingCoefficients<T>>;
The type of the UnsignedPolynomial generators that draw their coefficients from every u64 and their leading coefficients from every positive one, with lengths from a geometric distribution.

Aliased Type

pub struct RandomUnsignedPolynomialsFromUnsigneds<T>(/* private fields */);