Trait AbsSquared Copy item path Source pub trait AbsSquared {
type Output ;
// Required method
fn abs_squared (self) -> Self::Output ;
}Expand description Computes the squared absolute value of a number.
For a real number this is just its square, but for a complex number it is the sum of the squares
of its real and imaginary parts. In both cases it equals $|x|^2$; for Gaussian integers and
Gaussian rationals this quantity is also called the norm.
This trait is dyn compatible .
In older versions of Rust, dyn compatibility was called "object safety".
Computes the squared absolute value of a number. For real types this is the same as
squaring.
$f(x) = |x|^2 = x^2$.
 Worst-case complexity
Constant time and additional memory.
 Examples
See here .
Computes the squared absolute value of a number. For real types this is the same as
squaring.
$f(x) = |x|^2 = x^2$.
 Worst-case complexity
Constant time and additional memory.
 Examples
See here .
Computes the squared absolute value of a number. For real types this is the same as
squaring.
$f(x) = |x|^2 = x^2$.
 Worst-case complexity
Constant time and additional memory.
 Examples
See here .
Computes the squared absolute value of a number. For real types this is the same as
squaring.
$f(x) = |x|^2 = x^2$.
 Worst-case complexity
Constant time and additional memory.
 Examples
See here .
Computes the squared absolute value of a number. For real types this is the same as
squaring.
$f(x) = |x|^2 = x^2$.
 Worst-case complexity
Constant time and additional memory.
 Examples
See here .
Computes the squared absolute value of a number. For real types this is the same as
squaring.
$f(x) = |x|^2 = x^2$.
 Worst-case complexity
Constant time and additional memory.
 Examples
See here .
Computes the squared absolute value of a number. For real types this is the same as
squaring.
$f(x) = |x|^2 = x^2$.
 Worst-case complexity
Constant time and additional memory.
 Examples
See here .
Computes the squared absolute value of a number. For real types this is the same as
squaring.
$f(x) = |x|^2 = x^2$.
 Worst-case complexity
Constant time and additional memory.
 Examples
See here .
Computes the squared absolute value of a number. For real types this is the same as
squaring.
$f(x) = |x|^2 = x^2$.
 Worst-case complexity
Constant time and additional memory.
 Examples
See here .
Computes the squared absolute value of a number. For real types this is the same as
squaring.
$f(x) = |x|^2 = x^2$.
 Worst-case complexity
Constant time and additional memory.
 Examples
See here .
Computes the squared absolute value of a number. For real types this is the same as
squaring.
$f(x) = |x|^2 = x^2$.
 Worst-case complexity
Constant time and additional memory.
 Examples
See here .
Computes the squared absolute value of a number. For real types this is the same as
squaring.
$f(x) = |x|^2 = x^2$.
 Worst-case complexity
Constant time and additional memory.
 Examples
See here .
Computes the squared absolute value of a number. For real types this is the same as
squaring.
$f(x) = |x|^2 = x^2$.
 Worst-case complexity
Constant time and additional memory.
 Examples
See here .
Computes the squared absolute value of a number. For real types this is the same as
squaring.
$f(x) = |x|^2 = x^2$.
 Worst-case complexity
Constant time and additional memory.
 Examples
See here .