Trait BellNumber
Source pub trait BellNumber {
// Required method
fn bell_number(n: u64) -> Self;
}
Computes the $n$th Bell number: the number of ways to partition a set of $n$ elements.
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Computes the $n$th Bell number: the number of ways to partition a set of $n$
elements.
Worst-case complexity
Constant time and additional memory.
Panics
Panics if the result is too large to be represented.
Examples
See here.
Computes the $n$th Bell number: the number of ways to partition a set of $n$
elements.
Worst-case complexity
Constant time and additional memory.
Panics
Panics if the result is too large to be represented.
Examples
See here.
Computes the $n$th Bell number: the number of ways to partition a set of $n$
elements.
Worst-case complexity
Constant time and additional memory.
Panics
Panics if the result is too large to be represented.
Examples
See here.
Computes the $n$th Bell number: the number of ways to partition a set of $n$
elements.
Worst-case complexity
Constant time and additional memory.
Panics
Panics if the result is too large to be represented.
Examples
See here.
Computes the $n$th Bell number: the number of ways to partition a set of $n$
elements.
Worst-case complexity
Constant time and additional memory.
Panics
Panics if the result is too large to be represented.
Examples
See here.
Computes the $n$th Bell number: the number of ways to partition a set of $n$ elements.
Worst-case complexity
Constant time and additional memory.
Panics
Panics if the result is too large to be represented.
Examples
See here.