Trait CeilingRootAssign
Source pub trait CeilingRootAssign<POW> {
// Required method
fn ceiling_root_assign(&mut self, pow: POW);
}
Replaces a number with the ceiling of its $n$th root.
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Replaces an integer with the ceiling of its $n$th root.
$x \gets \lceil\sqrt[n]{x}\rceil$.
Worst-case complexity
Constant time and additional memory.
Panics
Panics if exp is zero, or if self is negative and exp is even.
Examples
See here.
Replaces an integer with the ceiling of its $n$th root.
$x \gets \lceil\sqrt[n]{x}\rceil$.
Worst-case complexity
Constant time and additional memory.
Panics
Panics if exp is zero, or if self is negative and exp is even.
Examples
See here.
Replaces an integer with the ceiling of its $n$th root.
$x \gets \lceil\sqrt[n]{x}\rceil$.
Worst-case complexity
Constant time and additional memory.
Panics
Panics if exp is zero, or if self is negative and exp is even.
Examples
See here.
Replaces an integer with the ceiling of its $n$th root.
$x \gets \lceil\sqrt[n]{x}\rceil$.
Worst-case complexity
Constant time and additional memory.
Panics
Panics if exp is zero, or if self is negative and exp is even.
Examples
See here.
Replaces an integer with the ceiling of its $n$th root.
$x \gets \lceil\sqrt[n]{x}\rceil$.
Worst-case complexity
Constant time and additional memory.
Panics
Panics if exp is zero, or if self is negative and exp is even.
Examples
See here.
Replaces an integer with the ceiling of its $n$th root.
$x \gets \lceil\sqrt[n]{x}\rceil$.
Worst-case complexity
Constant time and additional memory.
Panics
Panics if exp is zero, or if self is negative and exp is even.
Examples
See here.
Replaces an integer with the ceiling of its $n$th root.
$x \gets \lceil\sqrt[n]{x}\rceil$.
Worst-case complexity
Constant time and additional memory.
Panics
Panics if exp is zero, or if self is negative and exp is even.
Examples
See here.
Replaces an integer with the ceiling of its $n$th root.
$x \gets \lceil\sqrt[n]{x}\rceil$.
Worst-case complexity
Constant time and additional memory.
Panics
Panics if exp is zero, or if self is negative and exp is even.
Examples
See here.
Replaces an integer with the ceiling of its $n$th root.
$x \gets \lceil\sqrt[n]{x}\rceil$.
Worst-case complexity
Constant time and additional memory.
Panics
Panics if exp is zero, or if self is negative and exp is even.
Examples
See here.
Replaces an integer with the ceiling of its $n$th root.
$x \gets \lceil\sqrt[n]{x}\rceil$.
Worst-case complexity
Constant time and additional memory.
Panics
Panics if exp is zero, or if self is negative and exp is even.
Examples
See here.
Replaces an integer with the ceiling of its $n$th root.
$x \gets \lceil\sqrt[n]{x}\rceil$.
Worst-case complexity
Constant time and additional memory.
Panics
Panics if exp is zero, or if self is negative and exp is even.
Examples
See here.
Replaces an integer with the ceiling of its $n$th root.
$x \gets \lceil\sqrt[n]{x}\rceil$.
Worst-case complexity
Constant time and additional memory.
Panics
Panics if exp is zero, or if self is negative and exp is even.
Examples
See here.