Trait CheckedBellNumber
Source pub trait CheckedBellNumber: Sized {
// Required method
fn checked_bell_number(n: u64) -> Option<Self>;
}
Computes the $n$th Bell number, returning None if the result is too large to be represented.
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Computes the $n$th Bell number: the number of ways to partition a set of $n$
elements.
If the result is too large to be represented, the function returns None.
Worst-case complexity
Constant time and additional memory.
Examples
See here.
Computes the $n$th Bell number: the number of ways to partition a set of $n$
elements.
If the result is too large to be represented, the function returns None.
Worst-case complexity
Constant time and additional memory.
Examples
See here.
Computes the $n$th Bell number: the number of ways to partition a set of $n$
elements.
If the result is too large to be represented, the function returns None.
Worst-case complexity
Constant time and additional memory.
Examples
See here.
Computes the $n$th Bell number: the number of ways to partition a set of $n$
elements.
If the result is too large to be represented, the function returns None.
Worst-case complexity
Constant time and additional memory.
Examples
See here.
Computes the $n$th Bell number: the number of ways to partition a set of $n$
elements.
If the result is too large to be represented, the function returns None.
Worst-case complexity
Constant time and additional memory.
Examples
See here.
Computes the $n$th Bell number: the number of ways to partition a set of $n$ elements.
If the result is too large to be represented, the function returns None.
Worst-case complexity
Constant time and additional memory.
Examples
See here.