pub trait DivAssignModEuclidean<RHS = Self> {
type ModOutput;
// Required method
fn div_assign_mod_euclidean(&mut self, other: RHS) -> Self::ModOutput;
}Expand description
Divides a number by another number in place, returning the remainder. The quotient is rounded towards the quotient that makes the remainder nonnegative, and the remainder is always nonnegative.
The quotient and remainder satisfy $x = qy + r$ and $0 \leq r < |y|$.
Required Associated Types
Required Methods
fn div_assign_mod_euclidean(&mut self, other: RHS) -> Self::ModOutput
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl DivAssignModEuclidean for i8
impl DivAssignModEuclidean for i8
Sourcefn div_assign_mod_euclidean(&mut self, other: i8) -> i8
fn div_assign_mod_euclidean(&mut self, other: i8) -> i8
Divides a number by another number in place, returning the remainder. The quotient is rounded so that the remainder is nonnegative.
The quotient and remainder satisfy $x = qy + r$ and $0 \leq r < |y|$.
$$ f(x, y) = x - y \operatorname{sgn}(y) \left \lfloor \frac{x}{|y|} \right \rfloor, $$ $$ x \gets \operatorname{sgn}(y) \left \lfloor \frac{x}{|y|} \right \rfloor. $$
For unsigned integers, div_assign_mod_euclidean is equivalent to
div_assign_mod.
Worst-case complexity
Constant time and additional memory.
Panics
Panics if other is 0, or if self is $t::MIN and other is -1 (when $t is
signed).
Examples
See here.
type ModOutput = i8
Sourceimpl DivAssignModEuclidean for i16
impl DivAssignModEuclidean for i16
Sourcefn div_assign_mod_euclidean(&mut self, other: i16) -> i16
fn div_assign_mod_euclidean(&mut self, other: i16) -> i16
Divides a number by another number in place, returning the remainder. The quotient is rounded so that the remainder is nonnegative.
The quotient and remainder satisfy $x = qy + r$ and $0 \leq r < |y|$.
$$ f(x, y) = x - y \operatorname{sgn}(y) \left \lfloor \frac{x}{|y|} \right \rfloor, $$ $$ x \gets \operatorname{sgn}(y) \left \lfloor \frac{x}{|y|} \right \rfloor. $$
For unsigned integers, div_assign_mod_euclidean is equivalent to
div_assign_mod.
Worst-case complexity
Constant time and additional memory.
Panics
Panics if other is 0, or if self is $t::MIN and other is -1 (when $t is
signed).
Examples
See here.
type ModOutput = i16
Sourceimpl DivAssignModEuclidean for i32
impl DivAssignModEuclidean for i32
Sourcefn div_assign_mod_euclidean(&mut self, other: i32) -> i32
fn div_assign_mod_euclidean(&mut self, other: i32) -> i32
Divides a number by another number in place, returning the remainder. The quotient is rounded so that the remainder is nonnegative.
The quotient and remainder satisfy $x = qy + r$ and $0 \leq r < |y|$.
$$ f(x, y) = x - y \operatorname{sgn}(y) \left \lfloor \frac{x}{|y|} \right \rfloor, $$ $$ x \gets \operatorname{sgn}(y) \left \lfloor \frac{x}{|y|} \right \rfloor. $$
For unsigned integers, div_assign_mod_euclidean is equivalent to
div_assign_mod.
Worst-case complexity
Constant time and additional memory.
Panics
Panics if other is 0, or if self is $t::MIN and other is -1 (when $t is
signed).
Examples
See here.
type ModOutput = i32
Sourceimpl DivAssignModEuclidean for i64
impl DivAssignModEuclidean for i64
Sourcefn div_assign_mod_euclidean(&mut self, other: i64) -> i64
fn div_assign_mod_euclidean(&mut self, other: i64) -> i64
Divides a number by another number in place, returning the remainder. The quotient is rounded so that the remainder is nonnegative.
The quotient and remainder satisfy $x = qy + r$ and $0 \leq r < |y|$.
$$ f(x, y) = x - y \operatorname{sgn}(y) \left \lfloor \frac{x}{|y|} \right \rfloor, $$ $$ x \gets \operatorname{sgn}(y) \left \lfloor \frac{x}{|y|} \right \rfloor. $$
For unsigned integers, div_assign_mod_euclidean is equivalent to
div_assign_mod.
Worst-case complexity
Constant time and additional memory.
Panics
Panics if other is 0, or if self is $t::MIN and other is -1 (when $t is
signed).
Examples
See here.
type ModOutput = i64
Sourceimpl DivAssignModEuclidean for i128
impl DivAssignModEuclidean for i128
Sourcefn div_assign_mod_euclidean(&mut self, other: i128) -> i128
fn div_assign_mod_euclidean(&mut self, other: i128) -> i128
Divides a number by another number in place, returning the remainder. The quotient is rounded so that the remainder is nonnegative.
The quotient and remainder satisfy $x = qy + r$ and $0 \leq r < |y|$.
$$ f(x, y) = x - y \operatorname{sgn}(y) \left \lfloor \frac{x}{|y|} \right \rfloor, $$ $$ x \gets \operatorname{sgn}(y) \left \lfloor \frac{x}{|y|} \right \rfloor. $$
For unsigned integers, div_assign_mod_euclidean is equivalent to
div_assign_mod.
Worst-case complexity
Constant time and additional memory.
Panics
Panics if other is 0, or if self is $t::MIN and other is -1 (when $t is
signed).
Examples
See here.
type ModOutput = i128
Sourceimpl DivAssignModEuclidean for isize
impl DivAssignModEuclidean for isize
Sourcefn div_assign_mod_euclidean(&mut self, other: isize) -> isize
fn div_assign_mod_euclidean(&mut self, other: isize) -> isize
Divides a number by another number in place, returning the remainder. The quotient is rounded so that the remainder is nonnegative.
The quotient and remainder satisfy $x = qy + r$ and $0 \leq r < |y|$.
$$ f(x, y) = x - y \operatorname{sgn}(y) \left \lfloor \frac{x}{|y|} \right \rfloor, $$ $$ x \gets \operatorname{sgn}(y) \left \lfloor \frac{x}{|y|} \right \rfloor. $$
For unsigned integers, div_assign_mod_euclidean is equivalent to
div_assign_mod.
Worst-case complexity
Constant time and additional memory.
Panics
Panics if other is 0, or if self is $t::MIN and other is -1 (when $t is
signed).
Examples
See here.
type ModOutput = isize
Sourceimpl DivAssignModEuclidean for u8
impl DivAssignModEuclidean for u8
Sourcefn div_assign_mod_euclidean(&mut self, other: u8) -> u8
fn div_assign_mod_euclidean(&mut self, other: u8) -> u8
Divides a number by another number in place, returning the remainder. The quotient is rounded so that the remainder is nonnegative.
The quotient and remainder satisfy $x = qy + r$ and $0 \leq r < |y|$.
$$ f(x, y) = x - y \operatorname{sgn}(y) \left \lfloor \frac{x}{|y|} \right \rfloor, $$ $$ x \gets \operatorname{sgn}(y) \left \lfloor \frac{x}{|y|} \right \rfloor. $$
For unsigned integers, div_assign_mod_euclidean is equivalent to
div_assign_mod.
Worst-case complexity
Constant time and additional memory.
Panics
Panics if other is 0, or if self is $t::MIN and other is -1 (when $t is
signed).
Examples
See here.
type ModOutput = u8
Sourceimpl DivAssignModEuclidean for u16
impl DivAssignModEuclidean for u16
Sourcefn div_assign_mod_euclidean(&mut self, other: u16) -> u16
fn div_assign_mod_euclidean(&mut self, other: u16) -> u16
Divides a number by another number in place, returning the remainder. The quotient is rounded so that the remainder is nonnegative.
The quotient and remainder satisfy $x = qy + r$ and $0 \leq r < |y|$.
$$ f(x, y) = x - y \operatorname{sgn}(y) \left \lfloor \frac{x}{|y|} \right \rfloor, $$ $$ x \gets \operatorname{sgn}(y) \left \lfloor \frac{x}{|y|} \right \rfloor. $$
For unsigned integers, div_assign_mod_euclidean is equivalent to
div_assign_mod.
Worst-case complexity
Constant time and additional memory.
Panics
Panics if other is 0, or if self is $t::MIN and other is -1 (when $t is
signed).
Examples
See here.
type ModOutput = u16
Sourceimpl DivAssignModEuclidean for u32
impl DivAssignModEuclidean for u32
Sourcefn div_assign_mod_euclidean(&mut self, other: u32) -> u32
fn div_assign_mod_euclidean(&mut self, other: u32) -> u32
Divides a number by another number in place, returning the remainder. The quotient is rounded so that the remainder is nonnegative.
The quotient and remainder satisfy $x = qy + r$ and $0 \leq r < |y|$.
$$ f(x, y) = x - y \operatorname{sgn}(y) \left \lfloor \frac{x}{|y|} \right \rfloor, $$ $$ x \gets \operatorname{sgn}(y) \left \lfloor \frac{x}{|y|} \right \rfloor. $$
For unsigned integers, div_assign_mod_euclidean is equivalent to
div_assign_mod.
Worst-case complexity
Constant time and additional memory.
Panics
Panics if other is 0, or if self is $t::MIN and other is -1 (when $t is
signed).
Examples
See here.
type ModOutput = u32
Sourceimpl DivAssignModEuclidean for u64
impl DivAssignModEuclidean for u64
Sourcefn div_assign_mod_euclidean(&mut self, other: u64) -> u64
fn div_assign_mod_euclidean(&mut self, other: u64) -> u64
Divides a number by another number in place, returning the remainder. The quotient is rounded so that the remainder is nonnegative.
The quotient and remainder satisfy $x = qy + r$ and $0 \leq r < |y|$.
$$ f(x, y) = x - y \operatorname{sgn}(y) \left \lfloor \frac{x}{|y|} \right \rfloor, $$ $$ x \gets \operatorname{sgn}(y) \left \lfloor \frac{x}{|y|} \right \rfloor. $$
For unsigned integers, div_assign_mod_euclidean is equivalent to
div_assign_mod.
Worst-case complexity
Constant time and additional memory.
Panics
Panics if other is 0, or if self is $t::MIN and other is -1 (when $t is
signed).
Examples
See here.
type ModOutput = u64
Sourceimpl DivAssignModEuclidean for u128
impl DivAssignModEuclidean for u128
Sourcefn div_assign_mod_euclidean(&mut self, other: u128) -> u128
fn div_assign_mod_euclidean(&mut self, other: u128) -> u128
Divides a number by another number in place, returning the remainder. The quotient is rounded so that the remainder is nonnegative.
The quotient and remainder satisfy $x = qy + r$ and $0 \leq r < |y|$.
$$ f(x, y) = x - y \operatorname{sgn}(y) \left \lfloor \frac{x}{|y|} \right \rfloor, $$ $$ x \gets \operatorname{sgn}(y) \left \lfloor \frac{x}{|y|} \right \rfloor. $$
For unsigned integers, div_assign_mod_euclidean is equivalent to
div_assign_mod.
Worst-case complexity
Constant time and additional memory.
Panics
Panics if other is 0, or if self is $t::MIN and other is -1 (when $t is
signed).
Examples
See here.
type ModOutput = u128
Sourceimpl DivAssignModEuclidean for usize
impl DivAssignModEuclidean for usize
Sourcefn div_assign_mod_euclidean(&mut self, other: usize) -> usize
fn div_assign_mod_euclidean(&mut self, other: usize) -> usize
Divides a number by another number in place, returning the remainder. The quotient is rounded so that the remainder is nonnegative.
The quotient and remainder satisfy $x = qy + r$ and $0 \leq r < |y|$.
$$ f(x, y) = x - y \operatorname{sgn}(y) \left \lfloor \frac{x}{|y|} \right \rfloor, $$ $$ x \gets \operatorname{sgn}(y) \left \lfloor \frac{x}{|y|} \right \rfloor. $$
For unsigned integers, div_assign_mod_euclidean is equivalent to
div_assign_mod.
Worst-case complexity
Constant time and additional memory.
Panics
Panics if other is 0, or if self is $t::MIN and other is -1 (when $t is
signed).
Examples
See here.