pub trait ModPowerOf2Square {
type Output;
// Required method
fn mod_power_of_2_square(self, pow: u64) -> Self::Output;
}Expand description
Squares a number modulo $2^k$. The input must be already reduced modulo $2^k$.
Required Associated Types
Required Methods
fn mod_power_of_2_square(self, pow: u64) -> Self::Output
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl ModPowerOf2Square for u8
impl ModPowerOf2Square for u8
Sourcefn mod_power_of_2_square(self, pow: u64) -> u8
fn mod_power_of_2_square(self, pow: u64) -> u8
Squares a number modulo another number $2^k$. The input must be already reduced modulo $2^k$.
$f(x, k) = y$, where $x, y < 2^k$ and $x^2 \equiv y \mod 2^k$.
Worst-case complexity
Constant time and additional memory.
Panics
Panics if pow is greater than Self::WIDTH or if self is greater than or equal
to $2^k$.
Examples
See here.
type Output = u8
Sourceimpl ModPowerOf2Square for u16
impl ModPowerOf2Square for u16
Sourcefn mod_power_of_2_square(self, pow: u64) -> u16
fn mod_power_of_2_square(self, pow: u64) -> u16
Squares a number modulo another number $2^k$. The input must be already reduced modulo $2^k$.
$f(x, k) = y$, where $x, y < 2^k$ and $x^2 \equiv y \mod 2^k$.
Worst-case complexity
Constant time and additional memory.
Panics
Panics if pow is greater than Self::WIDTH or if self is greater than or equal
to $2^k$.
Examples
See here.
type Output = u16
Sourceimpl ModPowerOf2Square for u32
impl ModPowerOf2Square for u32
Sourcefn mod_power_of_2_square(self, pow: u64) -> u32
fn mod_power_of_2_square(self, pow: u64) -> u32
Squares a number modulo another number $2^k$. The input must be already reduced modulo $2^k$.
$f(x, k) = y$, where $x, y < 2^k$ and $x^2 \equiv y \mod 2^k$.
Worst-case complexity
Constant time and additional memory.
Panics
Panics if pow is greater than Self::WIDTH or if self is greater than or equal
to $2^k$.
Examples
See here.
type Output = u32
Sourceimpl ModPowerOf2Square for u64
impl ModPowerOf2Square for u64
Sourcefn mod_power_of_2_square(self, pow: u64) -> u64
fn mod_power_of_2_square(self, pow: u64) -> u64
Squares a number modulo another number $2^k$. The input must be already reduced modulo $2^k$.
$f(x, k) = y$, where $x, y < 2^k$ and $x^2 \equiv y \mod 2^k$.
Worst-case complexity
Constant time and additional memory.
Panics
Panics if pow is greater than Self::WIDTH or if self is greater than or equal
to $2^k$.
Examples
See here.
type Output = u64
Sourceimpl ModPowerOf2Square for u128
impl ModPowerOf2Square for u128
Sourcefn mod_power_of_2_square(self, pow: u64) -> u128
fn mod_power_of_2_square(self, pow: u64) -> u128
Squares a number modulo another number $2^k$. The input must be already reduced modulo $2^k$.
$f(x, k) = y$, where $x, y < 2^k$ and $x^2 \equiv y \mod 2^k$.
Worst-case complexity
Constant time and additional memory.
Panics
Panics if pow is greater than Self::WIDTH or if self is greater than or equal
to $2^k$.
Examples
See here.
type Output = u128
Sourceimpl ModPowerOf2Square for usize
impl ModPowerOf2Square for usize
Sourcefn mod_power_of_2_square(self, pow: u64) -> usize
fn mod_power_of_2_square(self, pow: u64) -> usize
Squares a number modulo another number $2^k$. The input must be already reduced modulo $2^k$.
$f(x, k) = y$, where $x, y < 2^k$ and $x^2 \equiv y \mod 2^k$.
Worst-case complexity
Constant time and additional memory.
Panics
Panics if pow is greater than Self::WIDTH or if self is greater than or equal
to $2^k$.
Examples
See here.