pub trait NegMod<RHS = Self> {
type Output;
// Required method
fn neg_mod(self, other: RHS) -> Self::Output;
}Expand description
Divides the negative of a number by another number, returning the remainder.
If the quotient were computed, the quotient and remainder would satisfy $x = qy - r$ and $0 \leq r < y$.
Required Associated Types
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl NegMod for u8
impl NegMod for u8
Sourcefn neg_mod(self, other: u8) -> u8
fn neg_mod(self, other: u8) -> u8
Divides the negative of a number by another number, returning just the remainder.
If the quotient were computed, the quotient and remainder would satisfy $x = qy - r$ and $0 \leq r < y$.
$$ f(x, y) = y\left \lceil \frac{x}{y} \right \rceil - x. $$
Worst-case complexity
Constant time and additional memory.
Panics
Panics if other is 0.
Examples
See here.
type Output = u8
Sourceimpl NegMod for u16
impl NegMod for u16
Sourcefn neg_mod(self, other: u16) -> u16
fn neg_mod(self, other: u16) -> u16
Divides the negative of a number by another number, returning just the remainder.
If the quotient were computed, the quotient and remainder would satisfy $x = qy - r$ and $0 \leq r < y$.
$$ f(x, y) = y\left \lceil \frac{x}{y} \right \rceil - x. $$
Worst-case complexity
Constant time and additional memory.
Panics
Panics if other is 0.
Examples
See here.
type Output = u16
Sourceimpl NegMod for u32
impl NegMod for u32
Sourcefn neg_mod(self, other: u32) -> u32
fn neg_mod(self, other: u32) -> u32
Divides the negative of a number by another number, returning just the remainder.
If the quotient were computed, the quotient and remainder would satisfy $x = qy - r$ and $0 \leq r < y$.
$$ f(x, y) = y\left \lceil \frac{x}{y} \right \rceil - x. $$
Worst-case complexity
Constant time and additional memory.
Panics
Panics if other is 0.
Examples
See here.
type Output = u32
Sourceimpl NegMod for u64
impl NegMod for u64
Sourcefn neg_mod(self, other: u64) -> u64
fn neg_mod(self, other: u64) -> u64
Divides the negative of a number by another number, returning just the remainder.
If the quotient were computed, the quotient and remainder would satisfy $x = qy - r$ and $0 \leq r < y$.
$$ f(x, y) = y\left \lceil \frac{x}{y} \right \rceil - x. $$
Worst-case complexity
Constant time and additional memory.
Panics
Panics if other is 0.
Examples
See here.
type Output = u64
Sourceimpl NegMod for u128
impl NegMod for u128
Sourcefn neg_mod(self, other: u128) -> u128
fn neg_mod(self, other: u128) -> u128
Divides the negative of a number by another number, returning just the remainder.
If the quotient were computed, the quotient and remainder would satisfy $x = qy - r$ and $0 \leq r < y$.
$$ f(x, y) = y\left \lceil \frac{x}{y} \right \rceil - x. $$
Worst-case complexity
Constant time and additional memory.
Panics
Panics if other is 0.
Examples
See here.
type Output = u128
Sourceimpl NegMod for usize
impl NegMod for usize
Sourcefn neg_mod(self, other: usize) -> usize
fn neg_mod(self, other: usize) -> usize
Divides the negative of a number by another number, returning just the remainder.
If the quotient were computed, the quotient and remainder would satisfy $x = qy - r$ and $0 \leq r < y$.
$$ f(x, y) = y\left \lceil \frac{x}{y} \right \rceil - x. $$
Worst-case complexity
Constant time and additional memory.
Panics
Panics if other is 0.
Examples
See here.