pub trait WrappingAbsAssign {
// Required method
fn wrapping_abs_assign(&mut self);
}Expand description
Replaces a number with its absolute value, wrapping around at the boundary of the type.
Required Methods
fn wrapping_abs_assign(&mut self)
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl WrappingAbsAssign for i8
impl WrappingAbsAssign for i8
Sourcefn wrapping_abs_assign(&mut self)
fn wrapping_abs_assign(&mut self)
Replaces a number with its absolute value, wrapping around at the boundary of the type.
$$
x \gets \begin{cases}
|x| & \text{if} \quad x > -2^{W-1}, \\
-2^{W-1} & \text{if} \quad x = -2^{W-1},
\end{cases}
$$
where $W$ is Self::WIDTH.
Worst-case complexity
Constant time and additional memory.
Examples
See here.
Sourceimpl WrappingAbsAssign for i16
impl WrappingAbsAssign for i16
Sourcefn wrapping_abs_assign(&mut self)
fn wrapping_abs_assign(&mut self)
Replaces a number with its absolute value, wrapping around at the boundary of the type.
$$
x \gets \begin{cases}
|x| & \text{if} \quad x > -2^{W-1}, \\
-2^{W-1} & \text{if} \quad x = -2^{W-1},
\end{cases}
$$
where $W$ is Self::WIDTH.
Worst-case complexity
Constant time and additional memory.
Examples
See here.
Sourceimpl WrappingAbsAssign for i32
impl WrappingAbsAssign for i32
Sourcefn wrapping_abs_assign(&mut self)
fn wrapping_abs_assign(&mut self)
Replaces a number with its absolute value, wrapping around at the boundary of the type.
$$
x \gets \begin{cases}
|x| & \text{if} \quad x > -2^{W-1}, \\
-2^{W-1} & \text{if} \quad x = -2^{W-1},
\end{cases}
$$
where $W$ is Self::WIDTH.
Worst-case complexity
Constant time and additional memory.
Examples
See here.
Sourceimpl WrappingAbsAssign for i64
impl WrappingAbsAssign for i64
Sourcefn wrapping_abs_assign(&mut self)
fn wrapping_abs_assign(&mut self)
Replaces a number with its absolute value, wrapping around at the boundary of the type.
$$
x \gets \begin{cases}
|x| & \text{if} \quad x > -2^{W-1}, \\
-2^{W-1} & \text{if} \quad x = -2^{W-1},
\end{cases}
$$
where $W$ is Self::WIDTH.
Worst-case complexity
Constant time and additional memory.
Examples
See here.
Sourceimpl WrappingAbsAssign for i128
impl WrappingAbsAssign for i128
Sourcefn wrapping_abs_assign(&mut self)
fn wrapping_abs_assign(&mut self)
Replaces a number with its absolute value, wrapping around at the boundary of the type.
$$
x \gets \begin{cases}
|x| & \text{if} \quad x > -2^{W-1}, \\
-2^{W-1} & \text{if} \quad x = -2^{W-1},
\end{cases}
$$
where $W$ is Self::WIDTH.
Worst-case complexity
Constant time and additional memory.
Examples
See here.
Sourceimpl WrappingAbsAssign for isize
impl WrappingAbsAssign for isize
Sourcefn wrapping_abs_assign(&mut self)
fn wrapping_abs_assign(&mut self)
Replaces a number with its absolute value, wrapping around at the boundary of the type.
$$
x \gets \begin{cases}
|x| & \text{if} \quad x > -2^{W-1}, \\
-2^{W-1} & \text{if} \quad x = -2^{W-1},
\end{cases}
$$
where $W$ is Self::WIDTH.
Worst-case complexity
Constant time and additional memory.
Examples
See here.