FromStringBase, a trait for converting strings in a specified
base to numbers.
Functions
- digit_
from_ display_ byte - Produces a digit from a byte corresponding to a numeric or alphabetic (lower- or uppercase)
charthat represents the digit. - digit_
from_ display_ byte_ large - Converts a byte corresponding to a numeric or alphabetic
charto a digit in the large-base alphabet used for bases from 37 through 62, in which the uppercase and lowercase letters are distinct digits:b'0'throughb'9'represent 0 through 9,b'A'throughb'Z'represent 10 through 35, andb'a'throughb'z'represent 36 through 61, as in GMP.