pub trait ModMakeMonic<M> {
type Output;
type Factor;
// Required method
fn mod_make_monic(self, m: M) -> Result<Self::Output, Self::Factor>;
}Expand description
Makes a polynomial monic modulo $m$, by multiplying it by the inverse of its leading coefficient.
The polynomial’s coefficients must already be reduced modulo $m$. If the leading coefficient is not invertible modulo $m$, its greatest common divisor with $m$, a nontrivial factor of $m$, is returned as the error. The zero polynomial is left as it is.
Required Associated Types
Required Methods
Sourcefn mod_make_monic(self, m: M) -> Result<Self::Output, Self::Factor>
fn mod_make_monic(self, m: M) -> Result<Self::Output, Self::Factor>
Makes a polynomial monic modulo m.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".