Iterators that generate sets randomly.
Structs
- RandomB
Tree Sets - Generates random
BTreeSets with lengths from an iterator. - RandomB
Tree Sets Fixed Length - Generates random
BTreeSets of a fixed length, where theVecs have no repeated elements, and the elements are in ascending order. - Random
Hash Sets - Generates random
HashSets with lengths from an iterator. - Random
Hash Sets Fixed Length - Generates random
HashSets of a fixed length, where theVecs have no repeated elements, and the elements are in ascending order.
Functions
- random_
b_ tree_ sets - Generates random
BTreeSets using elements from an iterator. - random_
b_ tree_ sets_ fixed_ length - Randomly generates
BTreeSets of a given length. - random_
b_ tree_ sets_ from_ length_ iterator - Generates random
BTreeSets using elements from an iterator and with lengths from another iterator. - random_
b_ tree_ sets_ length_ inclusive_ range - Generates random
BTreeSets with lengths in $[a, b]$, using elements from an iterator. - random_
b_ tree_ sets_ length_ range - Generates random
BTreeSets with lengths in $[a, b]$, using elements from an iterator. - random_
b_ tree_ sets_ min_ length - Generates random
BTreeSets with a minimum length, using elements from an iterator. - random_
hash_ sets - Generates random
HashSets using elements from an iterator. - random_
hash_ sets_ fixed_ length - Randomly generates
HashSets of a given length. - random_
hash_ sets_ from_ length_ iterator - Generates random
HashSets using elements from an iterator and with lengths from another iterator. - random_
hash_ sets_ length_ inclusive_ range - Generates random
HashSets with lengths in $[a, b]$, using elements from an iterator. - random_
hash_ sets_ length_ range - Generates random
HashSets with lengths in $[a, b)$, using elements from an iterator. - random_
hash_ sets_ min_ length - Generates random
HashSets with a minimum length, using elements from an iterator.