Module malachite_base::strings
source · Expand description
Functions for working with [String]s.
Modules
- Iterators that generate
Strings without repetition.
Structs
- Generates
Strings, given an iterator that generatesVec<char>s.
Traits
- A trait that provides an ergonomic way to create the string specified by a
Binaryimplementation. - A trait that provides an ergonomic way to create the string specified by a
Debugimplementation. - A trait that provides an ergonomic way to create the string specified by a
LowerHeximplementation. - A trait that provides an ergonomic way to create the string specified by an
Octalimplementation. - A trait that provides an ergonomic way to create the string specified by an
UpperHeximplementation.
Functions
- Returns whether all of the first string slice’s characters are present in the second string slice.
- Sorts the characters of a string slice and returns them in a new
String. - Takes a string slice’s unique characters and returns them in a new
String. - Generates
Strings, given an iterator that generatesVec<char>s.