The ToTypst trait, for converting a value to a Typst math-mode fragment, the
TypstWrapper struct that its to_typst method returns, and the
implementations for &str and String.
Structs
- Typst
Wrapper - A
structthat can be used to format a value as a Typst math-mode fragment.
Traits
- ToTypst
- Converts a value to a Typst math-mode fragment.